function ret=calcDistFromFlow(trans, rot, pts, flow)
  %% Given camera movement information, the points on the screen
  %% (without depth information) use the velocity of those points to
  %% calculate the distance to the points.
  %%
  %% See calcFlow.m for more information about this calculation.

  epsilon = 0.00001;

  T=trans;
  R=rot;

  for i=1:rows(pts)
    x = pts(i,1);
    y = pts(i,2);

    ## Calculate the flow we should see due to rotation
    uflowFromRot = R(1)*x*y - R(2)*(x*x+1) + R(3)*y;
    vflowFromRot = R(1)*(y*y+1) - R(2)*x*y - R(3)*x;

    ## Cancel out the flow due to rotation
    flowNoRot = [flow(i,1) - uflowFromRot,
		 flow(i,2) - vflowFromRot  ];

    ## If there is no flow after canceling out rotation:
    if(max(flowNoRot) < epsilon)
      ret(i,1) = nan;
    ## If there is some flow due to translation, calculate
    ## the distance using the direction where there is the
    ## largest magnitude of flow:
    elseif(abs(flowNoRot(1)) > abs(flowNoRot(2)))
      ret(i,1) = (-T(1) + x * T(3)) / flowNoRot(1);
    else
      ret(i,1) = (-T(2) + y * T(3)) / flowNoRot(2);
    endif

  endfor

endfunction

