function ret=calcFlow(trans,rot,pts,screenPts)
  %% Calculates the velocities of points on screen given the
  %% translational and angular velocities of a camera.  Assumes a
  %% perspective camera.
  %%
  %%
  %% rot is the angular rotations.  1st component is counterclockwise
  %% around x (when looking down X toward origin).  2nd is Y, 3rd is Z.
  %%
  %% pts are the xyz coords of the points in the world
  %%
  %% screenPts are where the pts are projected on the screen
  %%
  %%
  %% For explanation of equations, see: Bruss, A. R. & Horn B. K. P.
  %% (1983). Passive navigation.  Computer Vision, Graphics, and Image
  %% Processing, 21, 3-20.
  %%
  %% Author: Scott Kuhl

  T=trans;
  R=rot;

  if(rows(pts) != rows(screenPts))
    error("pts and screenPts have different numbers of rows");
  endif

  for i=1:rows(pts)
    x = screenPts(i,1);
    y = screenPts(i,2);
    z = pts(i,3);
    if(z==0)
      error("div by zero!");
    endif
    flow(i,1) = -T(1) / z - R(2) + R(3)*y - x*(-T(3)/z - R(1)*y+ R(2)*x);
    flow(i,2) = -T(2) / z - R(3)*x + R(1) - y*(-T(3)/z - R(1)*y+ R(2)*x);
  endfor

  ret=flow;

endfunction



