## clipPoints(points)
##
## Given a set of points (1 per row) that have been projected with
## projectPoints(), this function determine which points fall on the
## image plane.  This accounts for points that fall outside of the
## near/far planes and points that project outside of the -1 to 1 window
## for x and y.
##
## This function returns a vector with a length equal to the number of
## rows in the points matrix.  Points which project onto the image plane
## have a value of 1, points that don't have a value of zero.
##
## Author: Scott Kuhl <http://www.kuhlweb.com>
function ret=clipPoints(points)

  ## The z coordinate: -1 corresponds to the front of the z-buffer and 1
  ## corresponds to the back of the z-buffer.

  ## Figure out which values are outside of x=(-1,1), y=(-1,1), and
  ## z=(-1,1).  (i.e. outside of the window and the near/far plane).
  retbool =  points(:,1:3) > 1;
  retbool += points(:,1:3) < -1;

  ## Sum across the rows
  ret = sum(retbool, 2);

  ## If the value is 0, we passed all of the tests.
  ret = (ret==0);

endfunction
