function ret=closestPointBetweenLines(pos1, dir1,
				      pos2, dir2)
  %% Given two non-parallel lines, calculate the two points (one on each
  %% line) that are closest to each other and then calculate the point
  %% between those two points.  This will tell you the point in space
  %% where the lines intersect or the point in space (not on the lines)
  %% that is the closest to both lines.

  dir1 = dir1 ./ norm(dir1);
  dir2 = dir2 ./ norm(dir2);

  %% Find the direction of approach between the two lines (the direction
  %% of approach must be orthogonal to both lines
  approachDir = cross(dir1,dir2);

  if(norm(approachDir) < .0001)
    error("Lines are parallel or nearly parallel.  No intersection");
  endif

  approachDir = approachDir ./ norm(approachDir);

  %% find the plane normals for...
  %% ... the plane including line1 and the approach
  planeNorm1 = cross(dir1, approachDir);
  %% ... the plane including line2 and the approach
  planeNorm2 = cross(dir2, approachDir);

  %% Find the intersection of...
  %% .. the line1 and the plane (that includes line2 and approach)
  intersectLine1 = intersectLinePlane(pos1,dir1,pos2,planeNorm2);
  %% ... the line2 and the plane (that includes line1 and approach)
  intersectLine2 = intersectLinePlane(pos2,dir2,pos1,planeNorm1);

  %% Now that we have the points on the two lines where the lines are
  %% closest to each other, calculate the point between them.

  ret = (intersectLine1 + intersectLine2) / 2.0;

endfunction