## cylinderPoints(radius, height, numRadialPoints, numVertPoints)
##
## Creates points on a cylinder.  The cylinder is oriented along the y
## axis and centered at the origin.
##
## Author: Scott Kuhl <http://www.kuhlweb.com>

function ret=cylinderPoints(radius, height, numRadialPoints, \
			    numVertPoints)

### Much slower (but easier to understand) version.   
#  i = 1;
#  for j=1:numRadialPoints
#    for k=1:numVertPoints
#      ret(i,1:4) = [sin( j/numRadialPoints * 2*pi ) * radius
#		    (k/numVertPoints*height)-height/2  ## vertical
#		    cos( j/numRadialPoints * 2*pi ) * radius
#		    1 ]';
#      i++;
#    endfor
#  endfor
#  return

  for j=1:numRadialPoints

    ## compute all of the indicies for this radial position
    ## (numVertPoints will have the same x and z coords).
    loc = ((j-1)*numVertPoints)+1 : (j*numVertPoints);

    ## The x,z,w coords for this set of verticies will all ve the same
    ret(loc,1) = ones([numVertPoints 1]) .* sin( j/numRadialPoints * 2*pi ) .* radius;
    ret(loc,3) = ones([numVertPoints 1]) .* cos( j/numRadialPoints * 2*pi ) .* radius;

    ## The height (y) is varying for all of these coords.
    ret(loc,2) = ((((1:numVertPoints)./numVertPoints) .* height) .- height/2)';
  endfor

  if(rows(ret) != numVertPoints * numRadialPoints)
    error "Error in cylinderPoints().\n"
    return;
  endif

endfunction
