## Author: Scott Kuhl <http://www.kuhlweb.com>
##
## Creates an optic flow plot by projecting 3D points on an image plane
## before and after a movement (and drawing vectors indicating how the
## points moved).  See makePlot2.m for an example which creates a flow
## field which represents the instantanious velocity of points.
##
function makePlot()

  ## create projection matrix
  printf("Creating projection matrix...\n"); fflush(1);
  proj = perspective(35,1,.1,20);

  ## compute 3d points of cylinder
  printf("Creating cylinder...\n"); fflush(1);
  pts = cylinderPoints(1,1,100,50);
  printf("Rotating cylinder...\n"); fflush(1);
  rot_pts = multPoints(matRotDeg('y', 1), pts);

  ## translate the cylinder so it isn't centered around viewer
  printf("Translating cylinder...\n"); fflush(1);
  translationMat = matTrans([ -.5 0 0]);
  pts     = multPoints(translationMat, pts);
  rot_pts = multPoints(translationMat, rot_pts);

  ## project points onto image plane
  printf("Projecting points onto image plane...\n"); fflush(1);
  pts2d     = projectPoints(proj, pts);
  rot_pts2d = projectPoints(proj, rot_pts);

  ## clip points not in image or within near/far planes
  printf("Clipping projected points...\n"); fflush(1);
  good_pts = clipPoints(pts2d);
  good_rot_pts = clipPoints(rot_pts2d);

  ## Find indicies of points that fall on image before and after rotation.
  printf("Finding points to draw...\n"); fflush(1);
  igood_pts = good_pts .+ good_rot_pts;
  igood_pts = (igood_pts==2);

  ## compute delta vectors for points
  printf("Computing delta vectors...\n"); fflush(1);
  vecs = rot_pts2d(igood_pts,1:2) .- pts2d(igood_pts,1:2);

  ## Create a matrix needed to plot.
  pnt_and_delta = [pts2d(igood_pts,1:2)  vecs];

  if(sum(igood_pts) == 0)
    printf("No points fall on image!\n"); fflush(1);
    return
  else
    printf("%d points fall on image (before and after movement)\n", sum(igood_pts)); fflush(1);
  endif

  quiver(pnt_and_delta(:,1), pnt_and_delta(:,2),
	 pnt_and_delta(:,3), pnt_and_delta(:,4), 0);
  axis([-1 1 -1 1]);


endfunction
