%% Author: Scott Kuhl
%%
%% Creates an optic flow plot given:
%%  1) Points on the image plane (X,Y) and their distance (Z).
%%  2) Rate of camera translation
%%  3) Rate of camera rotation
%%

function makePlot2()
  scaleLongestVecTo=.1;  %% longest length of vectors in plot

  %% make a quad centered at (0,0,-5) on the xy plane.  It has width 2,2
  %% and points every .1 horizontally and vertically.
  pts = quadPoints(2,2, 21,21, [ 0 0 -5 ], [ 0 0 1 ]);

  %% Project points onto screen.
  screenPts = projectPoints(perspective(35,1,.1,20), pts);

  clipMask = clipPoints(screenPts);
  numClipped = length(clipMask) - sum(clipMask);
  printf("Clipped %d point(s)\n", numClipped);
  if(numClipped == rows(screenPts))
    error("All points were clipped.");
  endif

  %% Cull out the clipped points
  screenPts = screenPts(clipMask,:);
  pts = pts(clipMask,:);

  %% Camera information
  T = [ 0 0 1 ];  %% Rate of translation
  R = [ 0 0 0 ];  %% Rotation rate (Angular velocities)
  %% Calculate screen velocities
  flow = calcFlow(T,R,pts,screenPts);

  %% Calculate the largest amount of flow
  maxflow = 0;
  for i=1:rows(flow)
    if(norm(flow(i,:)) > maxflow)
      maxflow = norm(flow(i,:));
    endif
  endfor
  %% Check that we have some flow.
  if(maxflow < .00001)
    error("No points moved far enough to plot.  Longest flow: %f", maxflow);
  endif

  printf("Longest vector length: %f\n", maxflow);
  printf("Scaling flow values so the longest vector is %f in plot\n", scaleLongestVecTo);

  %% Create a matrix needed to plot.
  screenPts_and_delta = [ screenPts(:,1:2),   ((flow / maxflow)*scaleLongestVecTo)];

  quiver(screenPts_and_delta(:,1), screenPts_and_delta(:,2),
	 screenPts_and_delta(:,3), screenPts_and_delta(:,4), 0);
  axis([-1 1 -1 1]);

  %% Note that we don't need to know the FOV of the screen in order to
  %% calculate the distance to the point using camera
  %% translation/rotation+flow data.
  printf("Inverting equation...\n");
  calcDist = calcDistFromFlow(T,R,screenPts(:,1:2),flow);

  %% Now calcDist is set to the distance to the points

endfunction
