function ret=matRot(axis, radians)
%% Returns a rotation matrix that causes a point multiplied against it
%% to be rotated anti-clockwise when looking down the given radius
%% toward the origin.
%%
%% 'axis' is the axis to rotate around.
%%      Example: use axis='X', axis='x' or axis='1' to rotate around x
%%
%% 'radians': angle to rotate (clockwise when looking down axis from origin)
%% 

  a = radians;

  if(axis=='X' || axis=='x' || axis==1)
    %% rotation about x
    ret = [1   0       0    0
           0 cos(a) -sin(a) 0
	   0 sin(a)  cos(a) 0
	   0   0       0    1];

  elseif(axis=='Y' || axis=='y' || axis==2)
    %% rotation about y
    ret = [ cos(a)  0  sin(a) 0
	      0     1    0    0
	    -sin(a) 0  cos(a) 0
	      0     0    0    1 ];

  elseif(axis=='Z' || axis=='z' || axis==3)
    %% rotate about z
    ret = [cos(a) -sin(a)  0 0
           sin(a)  cos(a)  0 0
             0       0     1 0
	     0       0     0 1 ];
  else
    error("Invalid axis parameter");
  endif

endfunction