function ret=matRotToZ(vector)
  %% Returns a matrix that will rotate the given vector to the z-axis
  %%
  %% Author: Scott Kuhl

  if(norm(vector) == 0)
    error("norm(vector) == 0");
  endif

  v = vector ./ norm(vector);

  if(v(1) == 0 && v(2) == 0)
    if(v(3) > 0)
      %% No rotation needed
      ret = diag(ones(1,4), 0);
      return; 
    else
      %% 180 degree rotation needed
      ret = makeRotationRadians('y', pi);
      return;
    endif
  endif

  %% Rotate about the z-axis unil the vector is on the xz plane

  %% Length of vector's projection on xy plane.  We know it isn't zero
  %% since we already handled the case where the vector is parallel to
  %% the z-axis.
  d = sqrt(v(1)**2 + v(2)**2);

  Rz = [ v(1)/d   v(2)/d  0 0
	-v(2)/d   v(1)/d  0 0
	0            0    1 0
	0            0    0 1 ];

  %% Rotate the vector in the xz plane to the z-axis (i.e., rotate around y)
  Ry = [v(3) 0  -d   0
	0    1  0    0
	d    0  v(3) 0
	0    0  0    1 ];

  ret = Ry*Rz;

endfunction


