function ret=quadPoints(width, height, hpoints, vpoints, pos, perp)
  %% Creates a 1x1 quad with it's center at the pos and perpendicular to
  %% perp. hpoints and vpoints are the number of points that there are
  %% horizontally and vertically on the quad.

  if(hpoints < 2 || vpoints < 2)
    error("hpoints and vpoints must be 2 or greater");
  endif

  hstep = width  / (hpoints-1);
  vstep = height / (vpoints-1);

  %% make the quad centered at origin and on the xy plane
  i=1;
  for x=-height/2:vstep:height/2
    for y=-width/2:hstep:width/2
      pts(i,:) = [ x y 0 ];
      i++;
    endfor
  endfor

  %% z is now perpendicular to the quad.

  %% Calculate the amount we have to rotate the input vector to get it
  %% to the z-axis
  perpToZ = matRotToZ(perp);

  %% But, we want to rotate the z-axis to the perpendicular, and then
  %% translate:
  ret = multPoints(matTrans(pos)*perpToZ', pts);

endfunction
